pywingo.events API documentation

Top

# pywingo.events module

Show source ≡

    from collections import namedtuple

    def _new_Noop(j):
        assert j['EventName'] == 'Noop'
        return Noop()
    Noop = namedtuple('Noop', [])

    def _new_Restarting(j):
        assert j['EventName'] == 'Restarting'
        return Restarting()
    Restarting = namedtuple('Restarting', [])

    def _new_Subscribed(j):
        assert j['EventName'] == 'Subscribed'
        return Subscribed()
    Subscribed = namedtuple('Subscribed', [])

    def _new_ChangedWorkspace(j):
        assert j['EventName'] == 'ChangedWorkspace'
        return ChangedWorkspace()
    ChangedWorkspace = namedtuple('ChangedWorkspace', [])

    def _new_ChangedVisibleWorkspace(j):
        assert j['EventName'] == 'ChangedVisibleWorkspace'
        return ChangedVisibleWorkspace()
    ChangedVisibleWorkspace = namedtuple('ChangedVisibleWorkspace', [])

    def _new_ChangedWorkspaceNames(j):
        assert j['EventName'] == 'ChangedWorkspaceNames'
        return ChangedWorkspaceNames()
    ChangedWorkspaceNames = namedtuple('ChangedWorkspaceNames', [])

    def _new_AddedWorkspace(j):
        assert j['EventName'] == 'AddedWorkspace'
        return AddedWorkspace(j['Name'])
    AddedWorkspace = namedtuple('AddedWorkspace', ['Name'])

    def _new_RemovedWorkspace(j):
        assert j['EventName'] == 'RemovedWorkspace'
        return RemovedWorkspace(j['Name'])
    RemovedWorkspace = namedtuple('RemovedWorkspace', ['Name'])

    def _new_FocusedClient(j):
        assert j['EventName'] == 'FocusedClient'
        return FocusedClient(j['Id'])
    FocusedClient = namedtuple('FocusedClient', ['Id'])

    def _new_UnfocusedClient(j):
        assert j['EventName'] == 'UnfocusedClient'
        return UnfocusedClient(j['Id'])
    UnfocusedClient = namedtuple('UnfocusedClient', ['Id'])

    def _new_MappedClient(j):
        assert j['EventName'] == 'MappedClient'
        return MappedClient(j['Id'])
    MappedClient = namedtuple('MappedClient', ['Id'])

    def _new_UnmappedClient(j):
        assert j['EventName'] == 'UnmappedClient'
        return UnmappedClient(j['Id'])
    UnmappedClient = namedtuple('UnmappedClient', ['Id'])

    def _new_ManagedClient(j):
        assert j['EventName'] == 'ManagedClient'
        return ManagedClient(j['Id'])
    ManagedClient = namedtuple('ManagedClient', ['Id'])

    def _new_UnmanagedClient(j):
        assert j['EventName'] == 'UnmanagedClient'
        return UnmanagedClient(j['Id'], j['Name'], j['Workspace'], j['Class'], j['Instance'])
    UnmanagedClient = namedtuple('UnmanagedClient', ['Id', 'Name', 'Workspace', 'Class', 'Instance'])

    def _new_ChangedClientName(j):
        assert j['EventName'] == 'ChangedClientName'
        return ChangedClientName(j['Id'])
    ChangedClientName = namedtuple('ChangedClientName', ['Id'])

    def _new_ChangedActiveClient(j):
        assert j['EventName'] == 'ChangedActiveClient'
        return ChangedActiveClient(j['Id'])
    ChangedActiveClient = namedtuple('ChangedActiveClient', ['Id'])

    def _new_ChangedLayout(j):
        assert j['EventName'] == 'ChangedLayout'
        return ChangedLayout(j['Workspace'])
    ChangedLayout = namedtuple('ChangedLayout', ['Workspace'])

## Classes

class AddedWorkspace

AddedWorkspace(Name,)

### Ancestors (in MRO)

- AddedWorkspace
- __builtin__.tuple
- __builtin__.object

### Instance variables

var Name

Alias for field number 0

class ChangedActiveClient

ChangedActiveClient(Id,)

### Ancestors (in MRO)

- ChangedActiveClient
- __builtin__.tuple
- __builtin__.object

### Instance variables

var Id

Alias for field number 0

class ChangedClientName

ChangedClientName(Id,)

### Ancestors (in MRO)

- ChangedClientName
- __builtin__.tuple
- __builtin__.object

### Instance variables

var Id

Alias for field number 0

class ChangedLayout

ChangedLayout(Workspace,)

### Ancestors (in MRO)

- ChangedLayout
- __builtin__.tuple
- __builtin__.object

### Instance variables

var Workspace

Alias for field number 0

class ChangedVisibleWorkspace

ChangedVisibleWorkspace()

### Ancestors (in MRO)

- ChangedVisibleWorkspace
- __builtin__.tuple
- __builtin__.object

class ChangedWorkspace

ChangedWorkspace()

### Ancestors (in MRO)

- ChangedWorkspace
- __builtin__.tuple
- __builtin__.object

class ChangedWorkspaceNames

ChangedWorkspaceNames()

### Ancestors (in MRO)

- ChangedWorkspaceNames
- __builtin__.tuple
- __builtin__.object

class FocusedClient

FocusedClient(Id,)

### Ancestors (in MRO)

- FocusedClient
- __builtin__.tuple
- __builtin__.object

### Instance variables

var Id

Alias for field number 0

class ManagedClient

ManagedClient(Id,)

### Ancestors (in MRO)

- ManagedClient
- __builtin__.tuple
- __builtin__.object

### Instance variables

var Id

Alias for field number 0

class MappedClient

MappedClient(Id,)

### Ancestors (in MRO)

- MappedClient
- __builtin__.tuple
- __builtin__.object

### Instance variables

var Id

Alias for field number 0

class Noop

Noop()

### Ancestors (in MRO)

- Noop
- __builtin__.tuple
- __builtin__.object

class RemovedWorkspace

RemovedWorkspace(Name,)

### Ancestors (in MRO)

- RemovedWorkspace
- __builtin__.tuple
- __builtin__.object

### Instance variables

var Name

Alias for field number 0

class Restarting

Restarting()

### Ancestors (in MRO)

- Restarting
- __builtin__.tuple
- __builtin__.object

class Subscribed

Subscribed()

### Ancestors (in MRO)

- Subscribed
- __builtin__.tuple
- __builtin__.object

class UnfocusedClient

UnfocusedClient(Id,)

### Ancestors (in MRO)

- UnfocusedClient
- __builtin__.tuple
- __builtin__.object

### Instance variables

var Id

Alias for field number 0

class UnmanagedClient

UnmanagedClient(Id, Name, Workspace, Class, Instance)

### Ancestors (in MRO)

- UnmanagedClient
- __builtin__.tuple
- __builtin__.object

### Instance variables

var Class

Alias for field number 3

var Id

Alias for field number 0

var Instance

Alias for field number 4

var Name

Alias for field number 1

var Workspace

Alias for field number 2

class UnmappedClient

UnmappedClient(Id,)

### Ancestors (in MRO)

- UnmappedClient
- __builtin__.tuple
- __builtin__.object

### Instance variables

var Id

Alias for field number 0